@@ -285,7 +285,7 @@ static CommandArray commands[] = {
     {"includeonly", CmdIgnoreParameter, No_Opt_One_NormParam},
     {"nocite", CmdNoCite, No_Opt_One_NormParam},
     {"stepcounter", CmdIgnoreParameter, No_Opt_One_NormParam},
-    {"refstepcounter", CmdIgnoreParameter, No_Opt_One_NormParam},
+    {"refstepcounter", CmdCounter, COUNTER_INCR},
     {"fnsymbol", CmdIgnoreParameter, No_Opt_One_NormParam},
     {"Alph", CmdIgnoreParameter, No_Opt_One_NormParam},
     {"alph", CmdIgnoreParameter, No_Opt_One_NormParam},
